#include "testlib.h"
#include <sstream>

using namespace std;

const int max_electors = 50'000;

int main(int argc, char * argv[])
{
    setName("Check elections");

    registerTestlibCmd(argc, argv);

    auto solved = lowerCase(ouf.readToken("[a-zA-Z]+", "is_test_solved"));
    if (solved != "yes" && solved != "no") {
        quitf(_wa, "Expected yes/no as the first line");
    }
    if (solved != "yes") {
        quitf(_wa, "The test can be solved, but got 'No'");
    }

    int n = inf.readInt();
    int m = inf.readInt();
    vector<pair<int, int>> expected_edges;
    for (int i = 0; i < m; ++i) {
        int a = inf.readInt();
        int b = inf.readInt();
        expected_edges.emplace_back(a, b);
    }

    int electors = ouf.readInt(1, max_electors, "electors_cnt");
    map<pair<int, int>, int> balance;
    for (int id = 1; id <= electors; ++id) {
        vector<int> line(n);
        for (int i = 0; i < n; ++i) {
            line[i] = ouf.readInt(1, n, "elector_" + std::to_string(id) + "_" + std::to_string(i + 1));
        }

        ouf.ensuref(std::set(line.begin(), line.end()).size() == size_t(n), "elector %d repeats candidates", id);

        for (int i = 0; i < n; ++i) {
            for (int j = i + 1; j < n; ++j) {
                balance[std::make_pair(line[i], line[j])] += 1;
                balance[std::make_pair(line[j], line[i])] -= 1;
            }
        }
    }

    for (auto [a, b]: expected_edges) {
        auto balance_ab = balance[std::make_pair(a, b)];
        ouf.ensuref(balance_ab > 0, "expected %d beats %d, actual balance: %d", a, b, balance_ab);
    }

    ouf.ensuref(ouf.seekEof(), "Garbage at the end of file");
    ouf.quitf(_ok, "valid answer, electors: %d", electors);
}
