#include <bits/stdc++.h>
#include "testlib.h"
using namespace std;

const int MIN_N = 3;
const int MAX_N = 50;
const long long int MAX_INPUT_COORDINATES = 1'000'000'000LL;
long long int MAX_COORDINATES = MAX_N * MAX_INPUT_COORDINATES;


/**
 * @brief Computes the Manhattan distance between two points (x1,y1) and (x2,y2).
 */
long long manhattanDist(long long x1, long long y1, long long x2, long long y2) {
    return llabs(x1 - x2) + llabs(y1 - y2);
}

/**
 * @brief Reads and validates an answer ("YES"/"NO" + arrangement if "YES").
 *
 * @param in       The input stream (either ans or ouf).
 * @param n        Number of statues.
 * @param a, b     Coordinates where the nth statue must be placed.
 * @param d        Distances d_1, ..., d_{n-1}.
 * @return True if the file claims "YES" **and** the arrangement is valid;
 *         False if the file claims "NO".
 *         If any inconsistency is found, this function calls `quitf(_wa, ...)`.
 */
bool readAndCheckAnswer(InStream &in,
                        int n,
                        long long a,
                        long long b,
                        const vector<long long> &d)
{
    // Read token: must be "YES" or "NO".
    string result = in.readToken("YES|NO", "result");

    if (result == "NO") {
        // If the output states "NO", no further data should be read.
        return false;
    }

    // If result is "YES", we read n lines of statue coordinates.

    vector<long long> X(n), Y(n);
    for (int i = 0; i < n; i++) {
        X[i] = in.readLong(-MAX_COORDINATES, MAX_COORDINATES, format("x[%d]", i+1));
        in.readSpace();
        Y[i] = in.readLong(-MAX_COORDINATES, MAX_COORDINATES, format("y[%d]", i+1));
        in.readEoln();
    }

    // Check that the 1st statue is at (0,0).
    if (X[0] != 0 || Y[0] != 0) {
        in.quitf(_wa,
            "The 1st statue is not at (0, 0): got (%lld, %lld).", X[0], Y[0]);
    }

    // Check that the n-th statue is at (a,b).
    if (X[n-1] != a || Y[n-1] != b) {
        in.quitf(_wa,
            "The %d-th statue must be at (%lld, %lld), but got (%lld, %lld).",
            n, a, b, X[n-1], Y[n-1]);
    }

    // Check distances: distance between statue i and statue (i+1) must be d_i.
    for (int i = 0; i < n-1; i++) {
        long long dist = manhattanDist(X[i], Y[i], X[i+1], Y[i+1]);
        if (dist != d[i]) {
            in.quitf(_wa,
                "Distance between statue %d and %d is %lld, expected %lld.",
                i+1, i+2, dist, d[i]);
        }
    }

    // If all checks pass, the answer is valid and claims "YES."
    return true;
}

int main(int argc, char* argv[]) {
    // Register the checker with testlib
    registerTestlibCmd(argc, argv);

    // Read the original input from inf
    int n = inf.readInt(MIN_N, MAX_N, "n");
    inf.readEoln();

    long long a = inf.readLong(0, MAX_INPUT_COORDINATES, "a");
    inf.readSpace();
    long long b = inf.readLong(0, MAX_INPUT_COORDINATES, "b");
    inf.readEoln();

    vector<long long> d = inf.readLongs(n-1, 0LL, MAX_INPUT_COORDINATES, "d_i");
    inf.readEoln();

    // Check official solution (ans) first
    bool officialHasSolution = readAndCheckAnswer(ans, n, a, b, d);

    // Check participant's output (ouf)
    bool participantHasSolution = readAndCheckAnswer(ouf, n, a, b, d);

    // Compare official solution vs. participant output
    if (officialHasSolution == participantHasSolution) {
        // Both "NO" or both "YES+valid"
        quitf(_ok, "Matching verdicts (both %s)", officialHasSolution ? "YES" : "NO");
    }
    else if (participantHasSolution) {
        // Official says NO, but participant found a valid arrangement
        quitf(_fail, "Contestant found a valid arrangement whereas the official solution says NO!");
    }
    else {
        // Official says YES, but participant says NO
        quitf(_wa, "Valid arrangement not found.");
    }
}
