// Complexity is O(n^2*log(n)) because of divide-and-conquer.
// Idea from https://codeforces.com/blog/entry/59553#comment-432184

#include "testlib.h"
 
using namespace std;

using int64 = int64_t;
using int16 = int16_t;
using uint64 = uint64_t;

int64 count_rectangles(const vector<string>& fg, int hg, int wg) {

  vector<vector<int16>> upt(wg, vector<int16>(hg));
  vector<vector<int16>> upg(hg, vector<int16>(wg));
  for (int r = 0; r < hg; ++r) {
    for (int c = 0; c < wg; ++c) {
      if (fg[r][c] == '#') {
        upt[c][r] = 1;
        upg[r][c] = 1;
        if (c > 0) upt[c][r] += upt[c - 1][r];
        if (r > 0) upg[r][c] += upg[r - 1][c];
      }
    }
  }

  vector<vector<int16>> downt(wg, vector<int16>(hg));
  vector<vector<int16>> downg(hg, vector<int16>(wg));
  for (int r = hg - 1; r >= 0; --r) {
    for (int c = wg - 1; c >= 0; --c) {
      if (fg[r][c] == '#') {
        downt[c][r] = 1;
        downg[r][c] = 1;
        if (c + 1 < wg) downt[c][r] += downt[c + 1][r];
        if (r + 1 < hg) downg[r][c] += downg[r + 1][c];
      }
    }
  }

  vector<int> delta(max(hg, wg) + 2);
  vector<vector<int16>> acc(max(hg, wg), vector<int16>(max(hg, wg)));

  auto solve_subrectangle = [&](auto self, int h, int w, int r0, int c0, bool flip) -> int64 {
    if (h < 2 || w < 2) return 0;
    const auto& left = flip ? upg : upt;
    const auto& up = flip ? upt : upg;
    const auto& right = flip ? downg : downt;
    const auto& down = flip ? downt : downg;
    int mid = h / 2;
    int64 res = self(self, w, mid, c0, r0, !flip) + self(self, w, h - mid, c0, r0 + mid, !flip);
    const auto& top = up[r0 + mid - 1];
    const auto& bottom = down[r0 + mid];
    // Forward pass on top side.
    for (int c1 = c0; c1 < c0 + w; ++c1) {
      int tc1 = min<int>(top[c1], mid);
      fill(delta.begin() + c1 + 1, delta.begin() + c0 + w + 1, 0);
      const auto& dist = right[c1];
      for (int i = 0; i < tc1; ++i) {
        ++delta[c1 + dist[r0 + mid - 1 - i] + 1];
      }
      int remains = tc1;
      for (int c2 = c1 + 1; c2 < c0 + w; ++c2) {
        remains -= delta[c2 + 1];
        if (top[c2] >= tc1) {
          acc[c1][c2] = int16(remains);
        } else {
          acc[c1][c2] = 0;
        }
      }
    }
    // Backward pass on top side.
    for (int c1 = c0; c1 < c0 + w; ++c1) {
      int tc1 = min<int>(top[c1], mid);
      if (tc1 == mid) continue;
      fill(delta.begin() + c0 + 1, delta.begin() + c1 + 2, 0);
      const auto& dist = left[c1];
      for (int i = 0; i < tc1; ++i) {
        ++delta[c1 - dist[r0 + mid - 1 - i] + 1];
      }
      int remains = tc1;
      for (int c2 = c1 - 1; c2 >= c0; --c2) {
        remains -= delta[c2 + 1];
        if (top[c2] > tc1) {
          acc[c2][c1] += int16(remains);
        }
      }
    }
    // Forward pass on bottom side.
    for (int c1 = c0; c1 < c0 + w; ++c1) {
      int tc1 = min<int>(bottom[c1], h - mid);
      fill(delta.begin() + c1 + 1, delta.begin() + c0 + w + 1, 0);
      const auto& dist = right[c1];
      for (int i = 0; i < tc1; ++i) {
        ++delta[c1 + dist[r0 + mid + i] + 1];
      }
      int remains = tc1;
      for (int c2 = c1 + 1; c2 < c0 + w; ++c2) {
        remains -= delta[c2 + 1];
        if (bottom[c2] >= tc1) {
          res += remains * acc[c1][c2];
        }
      }
    }
    // Backward pass on bottom side.
    for (int c1 = c0; c1 < c0 + w; ++c1) {
      int tc1 = min<int>(bottom[c1], h - mid);
      if (tc1 == h - mid) continue;
      fill(delta.begin() + c0 + 1, delta.begin() + c1 + 2, 0);
      const auto& dist = left[c1];
      for (int i = 0; i < tc1; ++i) {
        ++delta[c1 - dist[r0 + mid + i] + 1];
      }
      int remains = tc1;
      for (int c2 = c1 - 1; c2 >= c0; --c2) {
        remains -= delta[c2 + 1];
        if (bottom[c2] > tc1) {
          res += remains * acc[c2][c1];
        }
      }
    }
    return res;
  };

  return solve_subrectangle(solve_subrectangle, hg, wg, 0, 0, false);
}

int64 count_rectangles_stupid(const vector<string>& f, int h, int w) {
  ensure(h <= 64);
  ensure(w <= 64);
  vector<uint64> rowMask(h);
  vector<uint64> colMask(w);
  for (int r = 0; r < h; ++r) {
    for (int c = 0; c < w; ++c) {
      if (f[r][c] == '#') {
        rowMask[r] |= uint64(1) << c;
        colMask[c] |= uint64(1) << r;
      }
    }
  }
  int64 res = 0;
  for (int r1 = 0; r1 < h; ++r1) {
    for (int r2 = r1 + 1; r2 < h; ++r2) {
      for (int c1 = 0; c1 < w; ++c1) {
        if (~(colMask[c1] >> r1) & ((uint64(1) << (r2 - r1 + 1)) - 1)) {
          continue;
        }
        for (int c2 = c1 + 1; c2 < w; ++c2) {
          if (~(colMask[c2] >> r1) & ((uint64(1) << (r2 - r1 + 1)) - 1)) {
            continue;
          }
          if (~(rowMask[r1] >> c1) & ((uint64(1) << (c2 - c1 + 1)) - 1)) {
            continue;
          }
          if (~(rowMask[r2] >> c1) & ((uint64(1) << (c2 - c1 + 1)) - 1)) {
            continue;
          }
          ++res;
        }
      }
    }
  }
  return res;
}

void stress() {
  while (true) {
    int h = rnd.next(1, 20);
    int w = rnd.next(1, 20);
    vector<string> f(h, string(w, '?'));
    for (int r = 0; r < h; ++r) {
      for (int c = 0; c < w; ++c) {
        f[r][c] = ".#"[min(1, rnd.next(0, 10))];
      }
    }
    int64 expected = count_rectangles_stupid(f, h, w);
    int64 actual = count_rectangles(f, h, w);
    ensure(expected == actual);
    //cerr << actual << " ";
  }
}
 
int main(int argc, char * argv[])
{ 
  setName("checker for Urban Planning");
  registerTestlibCmd(argc, argv);
  //stress();

  int64 k = inf.readLong();
  int h = ouf.readInteger(1, 2025, "h");
  int w = ouf.readInteger(1, 2025, "w");
  pattern p("[#.]{" + to_string(w) + "}");
  vector<string> f(h);
  for (auto& row : f) row = ouf.readToken(p, "grid");

  int64 got = count_rectangles(f, h, w);
  if (got != k) {
    quitf(_wa, "needed %lld rectangles, but got %lld", k, got);
  }

  quitf(_ok, "%lld rectangles, h=%d, w=%d", got, h, w);
}
