import java.util.*;

public class TranslationChatgpt {
    static final int[] dx = {-1, 0, 1, 0};
    static final int[] dy = {0, 1, 0, -1};
    static final int INF = 2000000000;

    public static void main(String[] args) {
        Scanner sc = new Scanner(System.in);

        int n = sc.nextInt();
        int m = sc.nextInt();
        sc.nextLine();  // Consume the newline character

        String[] v = new String[n + 2];
        v[0] = v[n + 1] = ".".repeat(m + 2);

        for (int i = 1; i <= n; ++i) {
            v[i] = "." + sc.nextLine() + ".";
        }

        n += 2; m += 2;

        int sx = -1, sy = -1;
        // Find the starting position 'S'
        for (int i = 0; i < n; ++i) {
            for (int j = 0; j < m; ++j) {
                if (v[i].charAt(j) == 'S') {
                    sx = i;
                    sy = j;
                    v[i] = v[i].substring(0, j) + '.' + v[i].substring(j + 1);
                }
            }
        }

        // Distances array initialized to INF
        int[][][] dist = new int[n][m][4];
        for (int i = 0; i < n; ++i) {
            for (int j = 0; j < m; ++j) {
                Arrays.fill(dist[i][j], INF);
            }
        }

        // Priority queue to store positions with their distances
        PriorityQueue<Tuple> pq = new PriorityQueue<>(Comparator.comparingInt(a -> -a.d));

        // Helper function to push the state into the priority queue
        // Push starting position for all 4 directions (0, 1, 2, 3)
        for (int sz = 0; sz < 4; ++sz) {
            push(pq, dist, v, sx, sy, sz, 0);
        }

        while (!pq.isEmpty()) {
            Tuple top = pq.poll();
            int d = -top.d;
            int x = top.x, y = top.y, z = top.z;

            if (d != dist[x][y][z]) continue;

            if (x == 0 || y == 0 || x == n - 1 || y == m - 1) {
                // Simulate the path from the end to the start
                int tm = 0;
                z = z ^ 2;
                List<Tuple> ans = new ArrayList<>();
                while (x != sx || y != sy) {
                    assert x >= 0 && y >= 0 && x < n && y < m;
                    tm++;

                    int nx = 0, ny = 0, nz = 0;
                    if ((v[x].charAt(y) == '\\' || v[x].charAt(y) == '/') &&
                            dist[x][y][z ^ 2] == (d - ans.size() - 1)) {
                        Tuple next = go(x, y, z, '.', v);
                        nx = next.x;
                        ny = next.y;
                        nz = next.z;
                        ans.add(new Tuple(tm, x, y, 0));
                    } else {
                        Tuple next = go(x, y, z, v[x].charAt(y), v);
                        nx = next.x;
                        ny = next.y;
                        nz = next.z;
                    }

                    x = nx;
                    y = ny;
                    z = nz;
                }

                Collections.reverse(ans);
                assert ans.size() == d;

                System.out.println("YES");
                System.out.println("URDL".charAt(z ^ 2));
                System.out.println(ans.size());
                for (Tuple t : ans) {
                    System.out.println((tm - t.d + 1) + " " + t.x + " " + t.y);
                }
                return;
            }

            int nx, ny, nz, nd = d;
            Tuple next = go(x, y, z, v[x].charAt(y), v);
            nx = next.x;
            ny = next.y;
            nz = next.z;
            push(pq, dist, v, nx, ny, nz, nd);

            if (v[x].charAt(y) == '/' || v[x].charAt(y) == '\\') {
                next = go(x, y, z, '.', v);
                nx = next.x;
                ny = next.y;
                nz = next.z;
                push(pq, dist, v, nx, ny, nz, nd + 1);
            }
        }

        System.out.println("NO");
    }

    // Method to simulate the movement based on the current direction and return new coordinates and direction
    static Tuple go(int x, int y, int z, char c, String[] v) {
        if (c == '/') {
            z ^= 1;  // Change direction based on '/'
        }
        if (c == '\\') {
            z ^= 3;  // Change direction based on '\'
        }

        int nx = x + dx[z];
        int ny = y + dy[z];

        // If the next position is a wall, reverse direction
        if (v[nx].charAt(ny) == '#') {
            nx = x;
            ny = y;
            z ^= 2;  // Reverse direction (flip 180 degrees)
        }

        return new Tuple(0, nx, ny, z);
    }

    // Method to push the state into the priority queue
    static void push(PriorityQueue<Tuple> pq, int[][][] dist, String[] v, int x, int y, int z, int d) {
        if (v[x].charAt(y) == '#' || dist[x][y][z] <= d) {
            return;
        }
        dist[x][y][z] = d;
        pq.add(new Tuple(-d, x, y, z));
    }

    // Tuple class to hold coordinates, distance, and direction
    static class Tuple {
        int d, x, y, z;

        Tuple(int d, int x, int y, int z) {
            this.d = d;
            this.x = x;
            this.y = y;
            this.z = z;
        }
    }
}
