n = int(input())

# freqs: the frequencies
# permutation: permutation that sorts the frequencies
# F: cumulative frequencies such that F(i) is sum of i least common frequencies
freqs = [round(float(i)*10000) for i in input().split()]
F,permutation = zip(*sorted([(f,i) for i,f in enumerate(freqs)]))
F = [0] + list(F)
for i in range(n):
    F[i+1] += F[i]

# Use DP to construct a tree bottom up, only keeping track of how many vertices there are at each depth.
# DP[a,c,d] is least expected value of a partial tree with
# a: number of still to assign frequencies
# c: number of leafs at current depth (that will either get assigned a frequency or split into two new leafs)
# d: number of leafs at next depth (one lower)
#
# initial value: DP[0,0,0] = 0
# required value: DP[n,1,0]
# transition: DP[a,c,d] = min(DP[a-1,c-1,d], DP[a,c+d,c] + F[a])
# out of bound cases: DP[a,c,d] = infinity if c < 0, c+d > a, or a > c = d = 0.
DP = [[[0]*(a-c+1) for c in range(a+1)] for a in range(n+1)]
for a in range(1,n+1):
    for c in reversed(range(a+1)):
        for d in reversed(range(a-c+1)):
            dp = 10**8
            if c>0: dp = min(dp,DP[a-1][c-1][d])
            if 0 < 2*c+d <= a: dp = min(dp, DP[a][c+d][c] + F[a])
            DP[a][c][d] = dp

# backtrack to reconstruct codes
a,c,d = n,1,0
codes = []
partial = [[]]
partial_next = []
while a:
    if c>0 and DP[a][c][d] == DP[a-1][c-1][d]:
        codes.append(''.join(partial.pop()))
        a,c,d = a-1,c-1,d
    else:
        partial,partial_next = partial_next + [i + ['.'] for i in partial], [i + ['-'] for i in partial]
        a,c,d = a,c+d,c

# permute codes into original order
new_codes = ['']*n
for i,j in enumerate(permutation):
    new_codes[j] = codes[n-1-i]
for i in new_codes:
    print(i)
