#include <bits/stdc++.h>
using namespace std;


#define rep(i, a, b) for(int i = a; i < (b); ++i)
#define trav(a, x) for(auto& a : x)
#define all(x) x.begin(), x.end()
#define sz(x) (int)(x).size()
typedef long long ll;
typedef pair<int, int> pii;
typedef vector<int> vi;

template <class T> int sgn(T x) { return (x > 0) - (x < 0); }
template<class T>
struct Point {
	typedef Point P;
	T x, y;
	explicit Point(T x=0, T y=0) : x(x), y(y) {}
	bool operator<(P p) const { return tie(x,y) < tie(p.x,p.y); }
	bool operator==(P p) const { return tie(x,y)==tie(p.x,p.y); }
	P operator+(P p) const { return P(x+p.x, y+p.y); }
	P operator-(P p) const { return P(x-p.x, y-p.y); }
	P operator*(T d) const { return P(x*d, y*d); }
	P operator/(T d) const { return P(x/d, y/d); }
	T dot(P p) const { return x*p.x + y*p.y; }
	T cross(P p) const { return x*p.y - y*p.x; }
	T cross(P a, P b) const { return (a-*this).cross(b-*this); }
	T dist2() const { return x*x + y*y; }
	double dist() const { return sqrt((double)dist2()); }
	// angle to x-axis in interval [-pi, pi]
	double angle() const { return atan2(y, x); }
	P unit() const { return *this/dist(); } // makes dist()=1
	P perp() const { return P(-y, x); } // rotates +90 degrees
	P normal() const { return perp().unit(); }
	// returns point rotated 'a' radians ccw around the origin
	P rotate(double a) const {
		return P(x*cos(a)-y*sin(a),x*sin(a)+y*cos(a)); }
	friend ostream& operator<<(ostream& os, P p) {
		return os << "(" << p.x << "," << p.y << ")"; }
};

template<class T>
vector<Point<T> > convexHull(vector<Point<T> > pts) {
	if (pts.size() <= 1) return pts;
	sort(pts.begin(), pts.end());
	vector<Point<T> > h(pts.size()+1);
	int s = 0, t = 0;
	for (int it = 2; it--; s = --t, reverse(pts.begin(), pts.end()))
		for (Point<T> p : pts) {
			while (t >= s + 2 && h[t-2].cross(h[t-1], p) <= 0) t--;
			h[t++] = p;
		}
	return {h.begin(), h.begin() + t - (t == 2 && h[0] == h[1])};
}

template<class T>
T polygonArea2(vector<Point<T>>& v) {
	T a = v.back().cross(v[0]);
	rep(i,0,sz(v)-1) a += v[i].cross(v[i+1]);
	return a;
}

int main(){
	ios_base::sync_with_stdio(false), cin.tie(nullptr);
	int N;
	cin >> N;
	vector<vector<int> > A(N, vector<int>(N));
	for(int i = 0; i < N; i++){
		for(int j = 0; j < N; j++){
			cin >> A[i][j];
		}
	}

	int D = N;

	int INF = 1e9;
	vector<vector<int> > best(2*D+1, vector<int>(2*D+1, INF));

	for(int x = 0; x < N; x++){
		for(int y = 0; y < N; y++){
			if(x != 0 && y != 0) continue;
			int L = N * (2*D+1);
			vector<vector<int> > H(L, vector<int>(L, INF));
			for(int i = 0; i < L; i++){
				for(int j = 0; j < L; j++){
					H[i][j] = A[i % N][j % N];
				}
			}
			int sx = x + N * D;
			int sy = y + N * D;
			vector<vector<int> > dist(L, vector<int>(L, INF));
			dist[sx][sy] = 0;
			using pq_t = pair<int, pair<int, int> >;
			priority_queue<pq_t, vector<pq_t>, greater<pq_t> > pq;
			pq.push({0, {sx, sy}});
			while(!pq.empty()){
				auto [d, p] = pq.top();
				pq.pop();
				if(dist[p.first][p.second] != d) continue;
				for(int dx = -1; dx <= 1; dx++){
					for(int dy = -1; dy <= 1; dy++){
						if(abs(dx) + abs(dy) != 1) continue;
						int nx = p.first + dx;
						int ny = p.second + dy;
						if(nx < 0 || nx >= L || ny < 0 || ny >= L) continue;
						if(abs(nx - sx) + abs(ny - sy) > N * N) continue;
						int nd = d + 1 + abs(H[nx][ny] - H[p.first][p.second]);
						if(nd < dist[nx][ny]){
							dist[nx][ny] = nd;
							pq.push({nd, {nx, ny}});
						}
					}
				}
			}
			for(int a = 0; a < (2 * D + 1); a++){
				for(int b = 0; b < (2 * D + 1); b++){
					best[a][b] = min(best[a][b], dist[a * N + x][b * N + y]);
				}
			}
		}
	}

	using ld = long double;
	using P = Point<ld>;
	vector<P> pts;
	for(int a = 0; a < (2 * D + 1); a++){
		for(int b = 0; b < (2 * D + 1); b++){
			int da = a - D;
			int db = b - D;
			if(da == 0 && db == 0) continue;
			pts.push_back(P(ld(da), ld(db)) / ld(best[a][b]));
		}
	}
	pts = convexHull(pts);
	auto area = polygonArea2(pts) / 2;
	area *= pow(10, 40) * N * N;
	cout << setprecision(10);
	cout << area << '\n';
}

