#include <bits/stdc++.h>
using namespace std;

namespace std {

template<class Fun>
class y_combinator_result {
	Fun fun_;
public:
	template<class T>
	explicit y_combinator_result(T &&fun): fun_(std::forward<T>(fun)) {}

	template<class ...Args>
	decltype(auto) operator()(Args &&...args) {
		return fun_(std::ref(*this), std::forward<Args>(args)...);
	}
};

template<class Fun>
decltype(auto) y_combinator(Fun &&fun) {
	return y_combinator_result<std::decay_t<Fun>>(std::forward<Fun>(fun));
}

} // namespace std

namespace ecnerwala {

using std::swap;

struct level_ancestor {
	int N;
	std::vector<int> preorder;
	std::vector<int> idx;
	std::vector<std::pair<int, int>> heavyPar; // heavy parent, distance
	level_ancestor() : N(0) {}

	level_ancestor(const std::vector<int>& par) : N(int(par.size())), preorder(N), idx(N), heavyPar(N) {
		std::vector<std::vector<int>> ch(N);
		for (int i = 0; i < N; i++) {
			if (par[i] != -1) ch[par[i]].push_back(i);
		}
		std::vector<int> sz(N);
		int nxt_idx = 0;
		for (int i = 0; i < N; i++) {
			if (par[i] == -1) {
				std::y_combinator([&](auto self, int cur) -> void {
					sz[cur] = 1;
					for (int nxt : ch[cur]) {
						self(nxt);
						sz[cur] += sz[nxt];
					}
					if (!ch[cur].empty()) {
						auto mit = max_element(ch[cur].begin(), ch[cur].end(), [&](int a, int b) { return sz[a] < sz[b]; });
						swap(*ch[cur].begin(), *mit);
					}
				})(i);
				std::y_combinator([&](auto self, int cur, int isRoot = true) -> void {
					preorder[idx[cur] = nxt_idx++] = cur;
					if (isRoot) {
						heavyPar[idx[cur]] = {par[cur] == -1 ? -1 : idx[par[cur]], 1};
					} else {
						assert(idx[par[cur]] == idx[cur]-1);
						heavyPar[idx[cur]] = heavyPar[idx[cur]-1];
						heavyPar[idx[cur]].second++;
					}
					bool chRoot = false;
					for (int nxt : ch[cur]) {
						self(nxt, chRoot);
						chRoot = true;
					}
				})(i);
			}
		}
	}

	int get_ancestor(int a, int k) const {
		assert(k >= 0);
		a = idx[a];
		while (a != -1 && k) {
			if (k >= heavyPar[a].second) {
				k -= heavyPar[a].second;
				assert(heavyPar[a].first <= a - heavyPar[a].second);
				a = heavyPar[a].first;
			} else {
				a -= k;
				k = 0;
			}
		}
		if (a == -1) return -1;
		else return preorder[a];
	}

	int lca(int a, int b) const {
		a = idx[a], b = idx[b];
		while (true) {
			if (a > b) swap(a, b);
			assert(a <= b);
			if (a > b - heavyPar[b].second) {
				return preorder[a];
			}
			b = heavyPar[b].first;
			if (b == -1) return -1;
		}
	}

	int dist(int a, int b) const {
		a = idx[a], b = idx[b];
		int res = 0;
		while (true) {
			if (a > b) swap(a, b);
			assert(a <= b);
			if (a > b - heavyPar[b].second) {
				res += b - a;
				break;
			}
			res += heavyPar[b].second;
			b = heavyPar[b].first;
			if (b == -1) return -1;
		}
		return res;
	}
};

} // namespace ecnerwala

int main(){
	ios_base::sync_with_stdio(false), cin.tie(nullptr);
	int N, M;
	cin >> N >> M;
	vector<vector<int> > adj(N);
	for(int i = 0; i < M; i++){
		int u, v;
		cin >> u >> v;
		u--; v--;
		adj[u].push_back(v);
		adj[v].push_back(u);
	}
	// bfs from N-1
	vector<int> dist(N, -1);
	vector<int> sp_par(N, -1);
	{
		queue<int> q;
		q.push(N-1);
		dist[N-1] = 0;
		while(!q.empty()){
			int d = q.front(); q.pop();
			for(int v : adj[d]){
				if(dist[v] == -1){
					dist[v] = dist[d] + 1;
					sp_par[v] = d;
					q.push(v);
				}
			}
		}
	}
	auto la = ecnerwala::level_ancestor(sp_par);

	const int INF = 1e8;
	vector<int> bad_dist(N, INF);

	vector<vector<int> > dist_ins(N);
	vector<vector<int> > dist_del(N);
	for(int v = 0; v < N; v++){
		for(int w : adj[v]){
			if(sp_par[w] == v || sp_par[v] == w) continue;
			int l = la.lca(v, w);
			if(l == v) continue;
			int del = dist[w] + 1;
			dist_ins[v].push_back(del);
			dist_del[l].push_back(del + dist[v] - dist[l]);
		}
	}
	vector<vector<int> > ch(N);
	for(int v = 0; v < N; v++){
		if(sp_par[v] != -1) ch[sp_par[v]].push_back(v);
	}
	vector<multiset<int>> work(N);
	vector<int> del(N);
	y_combinator([&](auto self, int v) -> int {
		int idx = v;
		del[idx] = 0;
		for(int c : dist_ins[v]){
			work[idx].insert(c);
		}
		for(int w : ch[v]){
			int cidx = self(w);
			del[cidx] += 1;
			if(work[cidx].size() > work[idx].size()) swap(idx, cidx);
			for(int c : work[cidx]){
				work[idx].insert(c + del[cidx] - del[idx]);
			}
		}
		for(int c : dist_del[v]){
			work[idx].erase(work[idx].find(c - del[idx]));
		}
		if(!work[idx].empty()){
			bad_dist[v] = *work[idx].begin() + del[idx];
		}
		return idx;
	})(N-1);
	bad_dist[N-1] = 0;
	int s = 0;
	int e = 2 * N + 1;
	while(s + 1 < e){
		int m = (s + e) / 2;
		vector<int> st_dist(N, INF);
		queue<int> q;
		if(bad_dist[0] <= m){
			st_dist[0] = 0;
			q.push(0);
		}
		while(!q.empty()){
			int v = q.front(); q.pop();
			for(int w : adj[v]){
				if(st_dist[w] == INF && bad_dist[w] <= m - (st_dist[v] + 1)){
					st_dist[w] = st_dist[v] + 1;
					q.push(w);
				}
			}
		}
		if(st_dist[N-1] < INF){
			e = m;
		} else {
			s = m;
		}
	}
	if(e > 2 * N){
		cout << -1 << '\n';
	} else {
		cout << e << '\n';
	}
}
