#include <bits/stdc++.h>
using namespace std;
 
int main(){
    ios::sync_with_stdio(false);
    cin.tie(nullptr);
    
    // Read the number of required words.
    int r;
    if(!(cin >> r)){
        return 1;
    }
    
    // Read all required words.
    vector<string> req(r);
    for (int i = 0; i < r; i++){
        cin >> req[i];
    }
    
    // Read the forbidden word.
    string forb;
    cin >> forb;
    int forbLen = forb.size();
    
    // For each required word, we maintain a pointer to the next letter that must appear.
    vector<int> ptr(r, 0);
    long long total = 0; // total number of forced letters (sum of lengths)
    for (int i = 0; i < r; i++){
        total += req[i].size();
    }
    
    // We will use 26 deques (one per lowercase letter) to hold the indices of required words 
    // whose next letter is that particular character.
    vector<deque<int>> avail(26);
    for (int i = 0; i < r; i++){
        if (!req[i].empty()){
            char c = req[i][0];
            avail[c - 'a'].push_back(i);
        }
    }
    
    // forbPtr simulates how many letters of the forbidden word F have been "matched"
    // so far in our answer S.
    int forbPtr = 0;
    
    string ans;
    ans.reserve(total);
    
    // We must output exactly 'total' forced letters (the interleaving of the required words).
    for (int move = 0; move < total; move++){
        // Determine the current forbidden target letter.
        char curForb = (forbPtr < forbLen ? forb[forbPtr] : '#'); // dummy if not needed
        
        bool madeMove = false;
        // Try to pick a "safe" move: an available forced letter that is NOT equal to curForb.
        // We iterate over all letters from 'a' to 'z'. (The order among safe moves is arbitrary.)
        for (int letter = 0; letter < 26; letter++){
            if (curForb == char('a' + letter)) continue; // skip if letter equals current forbidden target.
            if (!avail[letter].empty()){
                int idx = avail[letter].front();
                avail[letter].pop_front();
                char c = req[idx][ ptr[idx] ]; // c is safe because c != curForb.
                ans.push_back(c);
                ptr[idx]++;
                // If the required word idx still has letters, add it to the appropriate bucket.
                if (ptr[idx] < (int)req[idx].size()){
                    char nextChar = req[idx][ ptr[idx] ];
                    avail[nextChar - 'a'].push_back(idx);
                }
                madeMove = true;
                break;
            }
        }
        
        if(madeMove) continue;
        
        // No safe move exists; every available forced letter is equal to curForb.
        // We must now take a dangerous move.
        if(avail[curForb - 'a'].empty()){
            // (Should never happen: if some word isn’t finished, there is at least one forced letter.)
            break;
        }
        // If the current forbidden target is the last letter of forb then taking it would complete F.
        if(forbPtr == forbLen - 1){
            cout << "NO\n";
            return 0;
        }
        
        // Otherwise, take one forced letter equal to curForb and update the forbidden pointer.
        int idx = avail[curForb - 'a'].front();
        avail[curForb - 'a'].pop_front();
        ans.push_back(curForb);
        ptr[idx]++;
        forbPtr++; // dangerous move: we advanced the forbidden matching state.
        
        if(ptr[idx] < (int)req[idx].size()){
            char nextChar = req[idx][ ptr[idx] ];
            avail[nextChar - 'a'].push_back(idx);
        }
    }
    
    // Check that we have used all forced letters.
    if((int)ans.size() != total){
        cout << "NO\n";
        return 0;
    }
    
    // The constructed answer is an interleaving of the required words.
    // By construction, simulating the forbidden matching on 'ans' will never advance the pointer to forbLen,
    // so F is not a subsequence of ans.
    cout << "YES\n";
    cout << ans << "\n";
    return 0;
}

