#include <bits/stdc++.h>

using namespace std;

template <class Edge>
class Graph {
public:
    int vertexCount;
    int edgeCount = 0;
private:
    vector<vector<Edge>> edges;

public:
    Graph(int vertexCount) : vertexCount(vertexCount), edges(vertexCount, vector<Edge>()) {}

    template <typename...Ts>
    int addEdge(int from, int to, Ts... args) {
#ifdef LOCAL
        if (from < 0 || to < 0 || from >= vertexCount || to >= vertexCount) {
            throw "Out of bounds";
        }
#endif
        edges[from].emplace_back(to, edgeCount, args...);
        int directId = edges[from].size() - 1;
        if (Edge::reversable) {
            edges[to].push_back(edges[from][directId].reverseEdge(from));
            int revId = edges[to].size() - 1;
            edges[from][directId].setReverseId(revId);
            edges[to][revId].setReverseId(directId);
        }
        edgeCount++;
        return directId;
    }

    vector<Edge>& operator [](int at) {
        return edges[at];
    }

    void addVertices(int count) {
        vertexCount += count;
        edges.resize(vertexCount);
    }

    void clear() {
        edgeCount = 0;
        for (int i = 0; i < vertexCount; i++) {
            edges[i].clear();
        }
    }
};

class BaseEdge {
public:
    const static bool reversable = false;
    int to;
    int id;

    BaseEdge(int to, int id) : to(to), id(id) {
    }

    BaseEdge reverseEdge(int) {
        throw "Unsupported operation exception";
    }

    void setReverseId(int) {
        throw "Unsupported operation exception";
    }
};

class BiEdge : public BaseEdge {
public:
    const static bool reversable = true;
    int rev;

    BiEdge(int to, int id) : BaseEdge(to, id) {
    }

    void setReverseId(int revId) {
        rev = revId;
    }

    BiEdge reverseEdge(int from) {
        return BiEdge(from, id);
    }

    BiEdge& reverseEdge(Graph<BiEdge>& graph) {
        return graph[to][rev];
    }
};

template <typename C>
class FlowEdge : public BiEdge {
public:
    const static bool reversable = true;
    C capacity;
#ifdef LOCAL
    bool direct;
#endif

    FlowEdge(int to, int id, C capacity) : BiEdge(to, id), capacity(capacity) {
#ifdef LOCAL
        direct = true;
#endif
    }

    FlowEdge<C> reverseEdge(int from) {
        auto edge = FlowEdge<C>(from, id, 0);
#ifdef LOCAL
        edge.direct = false;
#endif
        return edge;
    }

    FlowEdge<C>& reverseEdge(Graph<FlowEdge<C>>& graph) const {
        return graph[to][rev];
    }

    void push(Graph<FlowEdge<C>>& graph, C flow) {
#ifdef LOCAL
        if (flow < 0 || flow > capacity) {
            throw "Invalid flow";
        }
#endif
        capacity -= flow;
        reverseEdge(graph).capacity += flow;
    }

    C flow(Graph<FlowEdge<C>>& graph) const {
        return reverseEdge(graph).capacity;
    }
};

template <class Edge, typename C>
C dinic(Graph<Edge>& graph, int source, int destination) {
    vector<int> dist(graph.vertexCount);
    vector<int> nextEdge(graph.vertexCount);
    C inf = numeric_limits<C>::max();
    C totalFlow = 0;
    queue<int> q;
    auto edgeDistances = [&]() {
        fill(dist.begin(), dist.end(), -1);
        dist[source] = 0;
        q.push(source);
        while (!q.empty()) {
            int current = q.front();
            q.pop();
            for (auto& edge : graph[current]) {
                if (edge.capacity != 0) {
                    int next = edge.to;
                    if (dist[next] == -1) {
                        dist[next] = dist[current] + 1;
                        q.push(next);
                    }
                }
            }
        }
    };
    function<C(int, C)> dinicImpl = [&](int source, C flow) -> C {
        if (source == destination) {
            return flow;
        }
        if (flow == 0 || dist[source] == dist[destination]) {
            return 0;
        }
        C totalPushed = 0;
        while (nextEdge[source] < graph[source].size()) {
            auto& edge = graph[source][nextEdge[source]];
            if (edge.capacity != 0 && dist[edge.to] == dist[source] + 1) {
                C pushed = dinicImpl(edge.to, min(flow, edge.capacity));
                if (pushed != 0) {
                    edge.push(graph, pushed);
                    flow -= pushed;
                    totalPushed += pushed;
                    if (flow == 0) {
                        return totalPushed;
                    }
                }
            }
            nextEdge[source]++;
        }
        return totalPushed;
    };

    while (true) {
        edgeDistances();
        if (dist[destination] == -1) {
            break;
        }
        fill(nextEdge.begin(), nextEdge.end(), 0);
        totalFlow += dinicImpl(source, inf);
    }
    return totalFlow;
}

int readInt() {
    int x;
    cin >> x;
    return x;
}

void solve() {
    auto n = readInt();
    vector<int> a(n);
    for (int i = 0; i < n; i++) {
        a[i] = readInt();
    }

    map<int, int> qty;
    for (int i : a) {
        qty[i]++;
    }
    auto ans = 0;
    map<int, vector<int>> q;
    vector<int> rem;
    vector<int> sh;
    set<int> forb;
    for (auto [x, y] : qty) {
        ans = max(ans, x);
        forb.insert(x);
        if (y > 1) {
            q[2 * x].push_back(rem.size());
            rem.push_back(y - 1);
            sh.push_back(x);
        }
    }
    Graph<FlowEdge<int>> graph(rem.size() + 2);
    auto source = rem.size();
    int notDone = 0;
    auto sink = rem.size() + 1;
    for (int i = 0; i < rem.size(); i++) {
        graph.addEdge(source, i, rem[i]);
        notDone += rem[i];
    }
    while (notDone > 0) {
        auto x = *q.begin();
        q.erase(q.begin());
        auto at = x.first;
        ans = max(ans, at);
        auto indices = x.second;
        if (forb.count(at) != 0) {
            for (auto i : indices) {
                q[at + sh[i]].push_back(i);
            }
            continue;
        }
        auto vertex = graph.vertexCount;
        graph.addVertices(1);
        graph.addEdge(vertex, sink, 1);
        for (auto i : indices) {
            graph.addEdge(i, vertex, 1);
        }
        auto flow = dinic<FlowEdge<int>, int>(graph, source, sink);
        if (flow == 1) {
            notDone--;
            for (auto i : indices) {
                q[at + sh[i]].push_back(i);
            }
        }
    }
    assert(notDone == 0);
    cout << ans << endl;
}

int main() {
    auto t = readInt();
    for (int i = 1; i <= t; i++) {
      solve();
    }
}
