#include <bits/stdc++.h>
using namespace std;

// Compute sum of a vector<long long>
long long sumVector(const vector<long long>& arr) {
    long long s = 0;
    for (auto &x : arr) s += x;
    return s;
}

// Manhattan distance
long long manhattanDist(long long x1, long long y1,
                        long long x2, long long y2) {
    return llabs(x1 - x2) + llabs(y1 - y2);
}

int main(){
    ios::sync_with_stdio(false);
    cin.tie(nullptr);

    // Read inputs
    int n;
    cin >> n;
    long long a,b;
    cin >> a >> b;  // final must be (a,b)
    vector<long long> d(n-1);
    for (int i = 0; i < n-1; i++){
        cin >> d[i];
    }

    // 1) Form L = d plus (a+b)
    vector<long long> L = d;
    L.push_back(a + b);

    // 2) Check sum(L) must be even, no distance > sum(L)/2
    long long T = sumVector(L);
    if ((T % 2LL) != 0) {
        // If sum is odd => NO
        cout << "NO\n";
        return 0;
    }
    long long M = *max_element(L.begin(), L.end());
    if (M > (T - M)) {
        // If one distance is strictly greater than sum of the others => NO
        cout << "NO\n";
        return 0;
    }

    // If we get here => a solution must exist in principle.
    // Next, we actually build statue coordinates so that:
    // (x_1,y_1)=(0,0), (x_n,y_n)=(a,b),
    // and dist((x_i,y_i),(x_{i+1},y_{i+1}))=d[i].

    // We'll store final statue coords in X[i], Y[i].
    vector<long long> X(n), Y(n);
    X[0] = 0;
    Y[0] = 0;

    // Place each statue #i in forward order
    for (int i = 0; i < n-1; i++) {
        long long distNeeded = d[i];
        // If i == n-2, we must place the last statue at (a,b).
        if (i == n-2) {
            // Check if we can be exactly distNeeded away from (x_{n-1}, y_{n-1}).
            long long direct = manhattanDist(X[i], Y[i], a, b);
            if (direct > distNeeded) {
                // Impossible to "shrink" the net distance to be exactly distNeeded
                // because we'd need negative leftover. => NO
                cout << "NO\n";
                return 0;
            }
            // leftover for zigzags = distNeeded - direct
            long long leftover = distNeeded - direct;
            if (leftover < 0 || (leftover % 2LL != 0)) {
                // We can't fix parity => NO
                cout << "NO\n";
                return 0;
            }
            // Otherwise we can do leftover/2 pairs of up-down or left-right in place
            // so final position is (a,b).
            X[i+1] = a;
            Y[i+1] = b;
        }
        else {
            // We want a position (nx, ny) s.t. dist((cx,cy),(nx,ny))=distNeeded
            // and the rest is feasible. "Feasible" means we can still place
            // statues #i+2..#n and end at (a,b).

            // We'll define a function that checks leftover feasibility:
            auto canFinish = [&](long long nx, long long ny, int idx) {
                // From statue #(idx+1) at (nx,ny), we have distances d[idx+1..(n-2)] left
                // plus eventually must get to (a,b).
                // We'll do a quick leftover sum + direct check:
                long long remainSum = 0;
                for (int j = idx+1; j < n-1; j++) {
                    remainSum += d[j];
                }
                // The direct from (nx,ny) to (a,b) is manhattanDist(nx,ny,a,b).
                long long dd = manhattanDist(nx, ny, a, b);
                if (dd > remainSum) return false;   // not enough distance
                // Also check parity (remainSum - dd) must be even
                return (((remainSum - dd) & 1LL) == 0);
            };

            long long cx = X[i], cy = Y[i];
            bool placed = false;
            // We'll attempt a small sign-based search for a coordinate (nx,ny)
            // on the diamond of radius distNeeded around (cx,cy).
            // Because n<=50, we can do a small approach that tries partial x in [0..distNeeded]
            // then y=distNeeded - x, with ± sign combos.

            // (For large d[i], enumerating 0..distNeeded is not feasible.
            //  We'll do a short set of candidate splits.
            //  But often you can do a simpler direct approach, e.g. put entire dist in x or y.
            //  We'll show a flexible sign approach.)

            // We'll define a few "split" values to try: 0, distNeeded, distNeeded/2
            // to find some feasible coordinate quickly.
            vector<long long> candidates;
            candidates.push_back(0);
            candidates.push_back(distNeeded);
            candidates.push_back(distNeeded/2);

            // Also push partial splits around distNeeded/2 to help parity
            long long half = distNeeded/2;
            candidates.push_back(half + 1);
            candidates.push_back(half - 1);

            // Keep them in range [0..distNeeded], remove duplicates
            sort(candidates.begin(), candidates.end());
            candidates.erase(unique(candidates.begin(), candidates.end()), candidates.end());
            // Trim to 0<=cand<=distNeeded
            vector<long long> validCands;
            for (auto c : candidates) {
                if (c >= 0 && c <= distNeeded) {
                    validCands.push_back(c);
                }
            }

            // Try each valid cand as the absolute x-split vs y-split
            for (auto xSplit : validCands) {
                long long ySplit = distNeeded - xSplit;

                // We'll do sign combos for xSplit,ySplit => 4 possibilities
                long long xOpts[2] = { cx + xSplit, cx - xSplit };
                long long yOpts[2] = { cy + ySplit, cy - ySplit };

                for (long long nx : xOpts) {
                    for (long long ny : yOpts) {
                        long long check = manhattanDist(cx, cy, nx, ny);
                        if (check == distNeeded && canFinish(nx, ny, i)) {
                            X[i+1] = nx;
                            Y[i+1] = ny;
                            placed = true;
                            break;
                        }
                    }
                    if (placed) break;
                }
                if (placed) break;
            }

            if (!placed) {
                // If we couldn't place statue #(i+1) anywhere feasible, fail
                cout << "NO\n";
                return 0;
            }
        }
    }

    // All n statues placed.
    // Double-check each pair's distance = d[i].
    for (int i = 0; i < n-1; i++) {
        long long check = manhattanDist(X[i], Y[i], X[i+1], Y[i+1]);
        if (check != d[i]) {
            // mismatch => something is off
            cout << "NO\n";
            return 0;
        }
    }
    // Also check final statue is (a,b)
    if (X[n-1] != a || Y[n-1] != b) {
        // shouldn't happen if the logic above is correct
        cout << "NO\n";
        return 0;
    }

    // If we reach here, success:
    cout << "YES\n";
    for (int i = 0; i < n; i++) {
        cout << X[i] << " " << Y[i] << "\n";
    }
    return 0;
}
